/*
 * This work is part of the White Rabbit Node Core project.
 *
 * Copyright (C) 2013-2014 CERN (www.cern.ch)
 * Author: Alessandro Rubini <rubini@gnudd.com>
 *
 * Released according to the GNU GPL, version 2 or any later version.
 */

#ifndef __TRTL_RT_PP_PRINTF_H
#define __TRTL_RT_PP_PRINTF_H

/**
 * @addtogroup trtl-rt-common
 * @{
 */

#include <stdarg.h>

/**
 * Include this code only if explicitly asked to
 */
#ifdef LIB_PRINTF

#define CONFIG_PRINT_BUFSIZE 128

extern int pp_printf(const char *fmt, ...)
        __attribute__((format(printf,1,2)));

extern int pp_sprintf(char *s, const char *fmt, ...)
        __attribute__((format(printf,2,3)));

extern int pp_vprintf(const char *fmt, va_list args);

extern int pp_vsprintf(char *buf, const char *, va_list args)
        __attribute__ ((format (printf, 2, 0)));

#else

/**
 * It prints a string on the serial interface
 * @param[in] fmt string format
 * @return number of printed characters
 */
static inline int pp_printf(const char *fmt, ...)
{
        return 0;
}


/**
 * It fills a buffer with a string
 * @param[out] s output string
 * @param[in] fmt string format
 * @return number of printed characters
 */
static inline int pp_sprintf(char *s, const char *fmt, ...)
{
        return 0;
}


/**
 * It prints a string on the serial interface
 * @param[in] fmt string format
 * @param[in] args list of arguments according to the string format
 * @return number of printed characters
 */
static inline int pp_vprintf(const char *fmt, va_list args)
{
        return 0;
}


/**
 * It fills a buffer with a string
 * @param[out] s output string
 * @param[in] fmt string format
 * @param[in] args list of arguments according to the string format
 * @return number of printed characters
 */
static inline int pp_vsprintf(char *buf, const char *fmt, va_list args)
{
        return 0;
}

#endif

/**@}*/

#endif
